@@ -2,8 +2,9 @@
 Der ISO-Landescode als Enumeration.
 """
 from enum import Enum
-from iso3166 import countries
+
+from iso3166 import countries  # type: ignore
 
 alpha2codes = {c.alpha2: c.alpha2 for c in countries}
 
-Landescode = Enum("Landescode", alpha2codes)
+Landescode = Enum("Landescode", alpha2codes)  # type: ignore
