@@ -1,5 +1,6 @@
 import json
-import pytest
+
+import pytest  # type:ignore[import]
 
 from bo4e.com.adresse import Adresse, AdresseSchema
 from bo4e.enum.landescode import Landescode
@@ -133,7 +134,6 @@ class TestAddress:
             address_test_data = json.load(json_file)
 
         with pytest.raises(TypeError) as excinfo:
-
             _ = Adresse(
                 ort=address_test_data["ort"],
                 strasse=address_test_data["strasse"],
@@ -192,9 +192,7 @@ class TestAddress:
         ],
     )
     def test_strasse_xor_postfach(self, address_test_data, expected):
-
         with pytest.raises(ValueError) as excinfo:
-
             _ = Adresse(
                 postleitzahl=address_test_data["postleitzahl"],
                 ort=address_test_data["ort"],
@@ -203,3 +201,17 @@ class TestAddress:
                 postfach=address_test_data["postfach"],
             )
         assert expected in str(excinfo.value)
+
+    def test_serialization_of_non_german_address(self):
+        """
+        Minimal working example
+        :return:
+        """
+        a = Adresse(
+            postleitzahl="6413", ort="Wildermieming", strasse="Gerhardhof", hausnummer="1", landescode=Landescode.AT
+        )
+        assert a.landescode == Landescode.AT
+        serialized_address = AdresseSchema().dumps(a)
+        assert '"AT"' in serialized_address
+        deserialized_address = AdresseSchema().loads(serialized_address)
+        assert deserialized_address.landescode == Landescode.AT
